@@ -78,9 +78,9 @@ static struct argp_option cmdline_options[] =
       "Get asset tag.", 31},
     { "set-asset-tag", SET_ASSET_TAG, "STRING", 0,
       "Set asset tag.", 32},
-    { "get-management-controller-identifier-string", GET_ASSET_TAG, NULL, 0,
+    { "get-management-controller-identifier-string", GET_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING, NULL, 0,
       "Get management controller identifier string.", 33},
-    { "set-management-controller-identifier-string", SET_ASSET_TAG, "STRING", 0,
+    { "set-management-controller-identifier-string", SET_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING, "STRING", 0,
       "Set management controller identifier string.", 34},
     { "get-dcmi-sensor-info", GET_DCMI_SENSOR_INFO, NULL, 0,
       "Get DCMI sensor information.", 35},
