@@ -1135,7 +1135,7 @@ set_asset_tag (ipmi_dcmi_state_data_t *state_data)
   fiid_obj_t obj_cmd_rs = NULL;
   unsigned int offset = 0;
   char data_buf[IPMI_DCMI_MAX_ASSET_TAG_LENGTH + 1];
-  unsigned int data_len = IPMI_DCMI_MAX_ASSET_TAG_LENGTH;
+  unsigned int data_len;
   uint8_t bytes_to_write = IPMI_DCMI_ASSET_TAG_NUMBER_OF_BYTES_TO_WRITE_MAX;
   int rv = -1;
 
@@ -1143,14 +1143,22 @@ set_asset_tag (ipmi_dcmi_state_data_t *state_data)
 
   /* achu:
    *
-   * DCMI 1.1 spec is unclear, I am assuming the
-   * "total_asset_tag_length_written" is the number of bytes just
-   * written.
+   * DCMI v1.1 spec is unclear if the entire buffer needs to be
+   * written or just the amount you desire.
    *
-   * I am assuming we need to clear the entire buffer, so we write the
-   * full buffer, NUL byte extended.
+   * DCMI v1.5 spec strongly suggests you don't write the entire
+   * buffer due to the results of the "total_asset_tag_length_written"
+   * field.
+   *
+   * "Total Asset Tag Length. This is the length in bytes of the stored
+   * Asset Tag after the Set operation has completed. The Asset Tag
+   * length shall be set to the sum of the offset to write plus bytes
+   * to write. For example, if offset to write is 32 and bytes to
+   * write is 4, the Total Asset Tag Length returned will be 36."
    */
 
+  data_len = strlen (state_data->prog_data->args->set_asset_tag_arg);
+
   memset (data_buf, '\0', IPMI_DCMI_MAX_ASSET_TAG_LENGTH + 1);
 
   memcpy (data_buf,
@@ -1170,8 +1178,7 @@ set_asset_tag (ipmi_dcmi_state_data_t *state_data)
     {
       uint64_t val;
 
-      if (!offset
-          || ((data_len - offset) >= IPMI_DCMI_ASSET_TAG_NUMBER_OF_BYTES_TO_WRITE_MAX))
+      if ((data_len - offset) >= IPMI_DCMI_ASSET_TAG_NUMBER_OF_BYTES_TO_WRITE_MAX)
         bytes_to_write = IPMI_DCMI_ASSET_TAG_NUMBER_OF_BYTES_TO_WRITE_MAX;
       else 
         bytes_to_write = data_len - offset;
@@ -1179,7 +1186,7 @@ set_asset_tag (ipmi_dcmi_state_data_t *state_data)
       if (ipmi_cmd_dcmi_set_asset_tag (state_data->ipmi_ctx,
                                        offset,
                                        bytes_to_write,
-                                       data_buf,
+                                       data_buf + offset,
                                        data_len,
                                        obj_cmd_rs) < 0)
         {
@@ -1201,10 +1208,12 @@ set_asset_tag (ipmi_dcmi_state_data_t *state_data)
           goto cleanup;
         }
 
-      /* make sure response is reasonable, some vendors may return the
-       * max length of the internal buffer.  If we get an unreasonable
-       * number, just assume bytes_to_write is what is added to the
-       * offset.
+      /* DCMI 1.1 spec is unclear on "total_length_written", is it the
+       * number of bytes just written or total bytes written so far?
+       * 
+       * DCMI 1.5 spec makes it clear that this is the number of bytes
+       * written in total.  To defend against vendor mistakes, we
+       * handle both situations.
        */
       if (val > bytes_to_write)
         offset += bytes_to_write;
@@ -1316,7 +1325,7 @@ set_management_controller_identifier_string (ipmi_dcmi_state_data_t *state_data)
   fiid_obj_t obj_cmd_rs = NULL;
   unsigned int offset = 0;
   char data_buf[IPMI_DCMI_MAX_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_LENGTH];
-  unsigned int data_len = IPMI_DCMI_MAX_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_LENGTH;
+  unsigned int data_len;
   uint8_t bytes_to_write = IPMI_DCMI_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_NUMBER_OF_BYTES_TO_WRITE_MAX;
   int rv = -1;
 
@@ -1324,17 +1333,19 @@ set_management_controller_identifier_string (ipmi_dcmi_state_data_t *state_data)
 
   /* achu:
    *
-   * DCMI 1.1 spec is unclear, I am assuming the
-   * "total_length_written" is the number of bytes just written.
+   * According to DCMI v1.5 draft
+   * 
+   * "The presence of the null terminator among bytes to shall be
+   * considered as indicating the last transfer of the Management
+   * Controller Identifier string"
    *
-   * I am assuming we need to clear the entire buffer, so we write the
-   * full buffer, NUL byte extended.
-   *
-   * Note that IPMI_DCMI_MAX_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_LENGTH
-   * length includes the NUL byte, so max string length is really
-   * (IPMI_DCMI_MAX_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_LENGTH - 1)
+   * So I am assuming we don't need to write the entire buffer.  But
+   * we must include the NUL byte at the end.
    */
 
+  /* +1 for NUL char */
+  data_len = strlen (state_data->prog_data->args->set_management_controller_identifier_string_arg) + 1;
+
   memset (data_buf, '\0', IPMI_DCMI_MAX_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_LENGTH);
 
   memcpy (data_buf,
@@ -1354,8 +1365,7 @@ set_management_controller_identifier_string (ipmi_dcmi_state_data_t *state_data)
     {
       uint64_t val;
 
-      if (!offset
-          || ((data_len - offset) >= IPMI_DCMI_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_NUMBER_OF_BYTES_TO_WRITE_MAX))
+      if ((data_len - offset) >= IPMI_DCMI_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_NUMBER_OF_BYTES_TO_WRITE_MAX)
         bytes_to_write = IPMI_DCMI_MANAGEMENT_CONTROLLER_IDENTIFIER_STRING_NUMBER_OF_BYTES_TO_WRITE_MAX;
       else 
         bytes_to_write = data_len - offset;
@@ -1363,7 +1373,7 @@ set_management_controller_identifier_string (ipmi_dcmi_state_data_t *state_data)
       if (ipmi_cmd_dcmi_set_management_controller_identifier_string (state_data->ipmi_ctx,
                                                                      offset,
                                                                      bytes_to_write,
-                                                                     data_buf,
+                                                                     data_buf + offset,
                                                                      data_len,
                                                                      obj_cmd_rs) < 0)
         {
@@ -1385,10 +1395,13 @@ set_management_controller_identifier_string (ipmi_dcmi_state_data_t *state_data)
           goto cleanup;
         }
 
-      /* make sure response is reasonable, some vendors may return the
-       * max length of the internal buffer.  If we get an unreasonable
-       * number, just assume bytes_to_write is what is added to the
-       * offset.
+
+      /* DCMI 1.1 spec is unclear on "total_length_written", is it the
+       * number of bytes just written or total bytes written so far?
+       * 
+       * DCMI 1.5 spec makes it clear that this is the number of bytes
+       * written in total.  To defend against vendor mistakes, we
+       * handle both situations.
        */
       if (val > bytes_to_write)
         offset += bytes_to_write;
