@@ -187,6 +187,10 @@ extern "C" {
  */
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTU_6PLUS 1549
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_3F    6
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8SIL_F     1541
+#define __IPMI_SUPERMICRO_PRODUCT_ID_X9SC      1572
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCL       __IPMI_SUPERMICRO_PRODUCT_ID_X9SC
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCM       __IPMI_SUPERMICRO_PRODUCT_ID_X9SC
 
 #ifdef __cplusplus
 }
