@@ -37,9 +37,10 @@
 
 #define IPMI_SENSOR_READ_CTX_MAGIC 0xABCD1246
 
-#define IPMI_SENSOR_READ_FLAGS_MASK        \
-  (IPMI_SENSOR_READ_FLAGS_BRIDGE_SENSORS   \
-   | IPMI_SENSOR_READ_FLAGS_DISCRETE_READING)
+#define IPMI_SENSOR_READ_FLAGS_MASK          \
+  (IPMI_SENSOR_READ_FLAGS_BRIDGE_SENSORS     \
+   | IPMI_SENSOR_READ_FLAGS_DISCRETE_READING \
+   | IPMI_SENSOR_READ_FLAGS_IGNORE_SCANNING_DISABLED)
 
 struct ipmi_sensor_read_ctx {
   uint32_t magic;
