@@ -49,7 +49,7 @@ extern "C" {
 
 #define LIBIPMIMONITORING_VERSION_MAJOR 1
 #define LIBIPMIMONITORING_VERSION_MINOR 0
-#define LIBIPMIMONITORING_VERSION_PATCH 0
+#define LIBIPMIMONITORING_VERSION_PATCH 1
 
 enum ipmi_monitoring_error_codes
   {
@@ -247,6 +247,7 @@ enum ipmi_monitoring_workaround_flags
 
     /* For use w/ an In-band driver */
     IPMI_MONITORING_WORKAROUND_FLAGS_INBAND_ASSUME_IO_BASE_ADDRESS                        = 0x00000001,
+    IPMI_MONITORING_WORKAROUND_FLAGS_INBAND_SPIN_POLL                                     = 0x00000002,	
   };
   
 /* REREAD_SDR_CACHE - Re-read the SDR cache
@@ -272,6 +273,12 @@ enum ipmi_monitoring_sel_flags
  * INTERPRET_OEM_DATA - Attempt to interpret OEM data if read.
  *
  * SHARED_SENSORS - Iterate through shared sensors if found
+ *
+ * DISCRETE_READING - Allow sensor readings to be read even if the event/reading type
+ *                    code for the sensor is not valid.  This option works around
+ *                    poorly defined (and arguably illegal) SDR records that list
+ *                    non-discrete sensor expectations along with discrete state
+ *                    conditions.
  */
 enum ipmi_monitoring_sensor_reading_flags
   {
@@ -280,6 +287,7 @@ enum ipmi_monitoring_sensor_reading_flags
     IPMI_MONITORING_SENSOR_READING_FLAGS_BRIDGE_SENSORS                   = 0x00000004,
     IPMI_MONITORING_SENSOR_READING_FLAGS_INTERPRET_OEM_DATA               = 0x00000008,
     IPMI_MONITORING_SENSOR_READING_FLAGS_SHARED_SENSORS                   = 0x00000010,
+    IPMI_MONITORING_SENSOR_READING_FLAGS_DISCRETE_READING                 = 0x00000020,
     IPMI_MONITORING_SENSOR_READING_FLAGS_IGNORE_UNREADABLE_SENSORS        = 0x00000002, /* legacy macro */
   };
 
